package com.chelvc.cloud.vehicle.api.param;

import com.chelvc.cloud.vehicle.api.constant.*;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import javax.validation.constraints.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 优惠券信息更新参数
 *
 * @author qizai
 * @date 2023/9/8
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class CouponModifyParam implements Serializable {
    /**
     * 商家ID
     */
    @NotNull(message = "商家ID不能为空")
	private Long merchantId;

    /**
     * 优惠券类型
     */
    @NotNull(message = "优惠券类型不能为空")
	private CouponType type;

    /**
     * 优惠券名称
     */
    @NotEmpty(message = "优惠券名称不能为空")
    @Size(max = 50, message = "优惠券名称长度不能大于50")
	private String name;

    /**
     * 优惠金额
     */
    @NotNull(message = "优惠金额不能为空")
    @DecimalMin(value = "0.00", message = "优惠金额不能小于0")
    private Double amount;

    /**
     * 满减金额
     */
    @NotNull(message = "消费门槛不能为空")
    @DecimalMin(value = "0.00", message = "消费门槛不能小于0")
    private Double consumeThreshold;

    /**
     * 优惠折扣
     */
    @NotNull(message = "优惠折扣不能为空")
    @DecimalMin(value = "0.00", message = "优惠折扣不能小于0")
    private Double discount;

    /**
     * 优惠券描述
     */
    @NotEmpty(message = "优惠券描述不能为空")
    @Size(max = 100, message = "优惠券描述长度不能大于100")
    private String description;

    /**
     * 优惠券状态
     */
    @NotNull(message = "优惠券状态不能为空")
    private PromotionStatus status;

    /**
     * 限制领取数量
     */
    @NotNull(message = "限制领取数量不能为空")
    @Min(value = 0, message = "限制领取数量不能小于0")
    private Integer limitNum;

    /**
     * 发行数量
     */
    @NotNull(message = "发行数量不能为空")
    @Min(value = 0, message = "发行数量不能小于0")
    private Integer publishNum;

    /**
     * 优惠券ID列表
     */
    private List<Long> ids;

    /**
     * 活动开始时间
     */
    @NotNull(message = "活动开始时间不能为空")
    private Date startTime;

    /**
     * 活动结束时间
     */
    @NotNull(message = "活动结束时间不能为空")
    private Date endTime;

    /**
     * 优惠券领取方式
     */
    @NotNull(message = "优惠券领取方式不能为空")
    private CouponClaimType claimType;

    /**
     * 范围关联的id
     */
    private String scopeId;

    /**
     * 优惠券使用范围
     */
    @NotNull(message = "优惠券使用范围不能为空")
    private PromotionScopeType scopeType;

    /**
     * 时间范围类型
     */
    @NotNull(message = "间范围类型不能为空")
    private CouponRangeDay rangeDayType;
}