package com.chelvc.cloud.vehicle.api.param;

import com.chelvc.cloud.vehicle.api.constant.CouponClaimType;
import com.chelvc.cloud.vehicle.api.constant.CouponType;
import com.chelvc.cloud.vehicle.api.constant.PromotionScopeType;
import com.chelvc.cloud.vehicle.api.constant.UserCouponStatus;
import com.chelvc.framework.common.model.Paging;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Date;

/**
 * 优惠券领取记录查询参数
 *
 * @author 七仔
 * @date 2023/3/29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class UserCouponPagingParam implements Serializable {
    /**
     * 分页信息
     */
    @NotNull(message = "分页不能为空")
    private Paging paging;

    /**
     * 关键字
     */
    @Size(max = 100, message = "关键字长度不能大于100")
    private String keyword;

    /**
     * 优惠券类型
     */
    private CouponType type;

    /**
     * 用户优惠券状态
     */
    private UserCouponStatus status;

    /**
     * 优惠券ID
     */
    private Long couponId;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 商家ID
     */
    private Long merchantId;

    /**
     * 优惠券名称
     */
    private String couponName;

    /**
     * 用户名称
     */
    private String userName;

    /**
     * 优惠券领取方式
     */
    private CouponClaimType claimType;

    /**
     * 关联范围类型
     */
    private PromotionScopeType scopeType;

    /**
     * 活动开始时间
     */
    private Date startTime;

    /**
     * 活动结束时间
     */
    private Date endTime;
}
