package com.chelvc.cloud.vehicle.api.service;

import com.chelvc.cloud.vehicle.api.dto.CouponActivityDTO;
import com.chelvc.cloud.vehicle.api.dto.CouponDTO;
import com.chelvc.cloud.vehicle.api.param.CouponActivityModifyParam;
import com.chelvc.cloud.vehicle.api.param.CouponActivityPagingParam;
import com.chelvc.framework.common.model.Pagination;

/**
 * 优惠券活动业务接口
 *
 * @author qizai
 * @date 2023/11/10
 */
public interface CouponActivityService {
    /**
     * 新增优惠券活动
     *
     * @param param 新增参数
     * @return 优惠券活动主键
     */
    Long addCouponActivity(CouponActivityModifyParam param);

    /**
     * 修改优惠券活动
     *
     * @param id    优惠券活动主键
     * @param param 修改参数
     */
    void updateCouponActivity(Long id, CouponActivityModifyParam param);

    /**
     * 删除优惠券活动
     *
     * @param id    优惠券活动主键
     */
    void deleteCouponActivity(Long id);

    /**
     * 获取优惠券活动信息
     *
     * @param id 优惠券活动主键
     * @return 优惠券活动信息
     */
    CouponActivityDTO getCouponActivity(Long id);

    /**
     * 查询优惠券活动信息
     *
     * @param param 查询参数
     * @return 优惠券活动分页信息
     */
    Pagination<CouponActivityDTO> getCouponActivityPaging(CouponActivityPagingParam param);

    /**
     * 保存优惠券活动
     *
     * @param param 新增参数
     * @return 优惠券活动主键
     */
    Long saveCouponActivity(CouponActivityModifyParam param);
}
