package com.chelvc.cloud.vehicle.server.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.chelvc.cloud.vehicle.api.constant.PromotionScopeType;
import com.chelvc.cloud.vehicle.api.constant.PromotionStatus;
import com.chelvc.framework.database.entity.BasicEntity;
import com.chelvc.framework.database.interceptor.DeletedTypeHandler;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.util.Date;

/**
 * 促销活动基础数据模型
 *
 * @author qizai
 * @date 2023/11/10
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class BasePromotion extends BasicEntity<Long> {

    /**
     * 主键
     */
    @TableId(type = IdType.AUTO)
    private Long id;

    /**
     * 商家名称，如果是平台，这个值为platform
     */
    private String merchantName;

    /**
     * 商家id，如果是平台，这个值为0
     */
    private Long merchantId;

    /**
     * 活动名称
     */
    private String promotionName;

    /**
     * 活动开始时间
     */
    private Date startTime;

    /**
     * 活动结束时间
     */
    private Date endTime;

    /**
     * 关联范围类型
     */
    private PromotionScopeType scopeType = PromotionScopeType.ALL;

    /**
     * 范围关联的id
     */
    private String scopeId;

    /**
     * 是否已删除
     */
    @TableField(typeHandler = DeletedTypeHandler.class)
    private Boolean deleted;


    /**
     * @return 促销状态
     */
    public String getPromotionsStatus() {
        if (endTime == null) {
            return startTime != null ? PromotionStatus.START.name() : PromotionStatus.CLOSE.name();
        }
        Date now = new Date();
        if (now.before(startTime)) {
            return PromotionStatus.NEW.name();
        } else if (endTime.before(now)) {
            return PromotionStatus.END.name();
        } else if (now.before(endTime)) {
            return PromotionStatus.START.name();
        }
        return PromotionStatus.CLOSE.name();
    }
}
