package com.chelvc.cloud.vehicle.server.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.chelvc.cloud.vehicle.api.constant.PromotionType;
import com.chelvc.cloud.vehicle.api.param.BasePromotionQueryParam;
import com.chelvc.cloud.vehicle.server.entity.BasePromotion;

import java.util.Date;
import java.util.List;

/**
 * 抽象通用促销服务
 *
 * @author qizai
 * @date 2023/11/12
 */
public interface AbstractPromotionService<T extends BasePromotion> extends IService<T> {

    /**
     * 通用促销保存
     * 调用顺序:
     * 1. initPromotion 初始化促销信息
     * 2. checkPromotion 检查促销参数
     * 3. save 保存促销信息
     * 4. updatePromotionGoods 更新促销商品信息
     * 5。 updateEsGoodsIndex 更新商品索引促销信息
     *
     * @param promotion 促销信息
     * @return 是否保存成功
     */
    boolean savePromotion(T promotion);

    /**
     * 通用促销更新
     * 调用顺序:
     * 1. checkStatus 检查促销状态
     * 2. checkPromotion 检查促销参数
     * 3. saveOrUpdate 保存促销信息
     * 4. updatePromotionGoods 更新促销商品信息
     * 5. updateEsGoodsIndex 更新商品索引促销信息
     *
     * @param promotions 促销信息
     * @return 是否更新成功
     */
    boolean updatePromotion(T promotions);

    /**
     * 更新促销状态
     * 如果要更新促销状态为关闭，startTime和endTime置为空即可
     *
     * @param ids       促销id集合
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @return 是否更新成功
     */
    boolean updateStatus(List<Long> ids, Date startTime, Date endTime);

    /**
     * 移除促销活动
     *
     * @param ids 促销活动id集合
     * @return 是否移除成功
     */
    boolean removePromotion(List<Long> ids);

    /**
     * 初始化促销字段
     *
     * @param promotion 促销实体
     */
    void initPromotion(T promotion);

    /**
     * 检查促销参数
     *
     * @param promotions 促销实体
     */
    void checkPromotion(T promotions);

    /**
     * 检查促销状态
     *
     * @param promotions 促销实体
     */
    void checkStatus(T promotions);

    /**
     * 更新促销商品信息
     *
     * @param promotions 促销实体
     * @return
     */
    boolean updatePromotionsGoods(T promotions);

    /**
     * 更新促销信息到商品索引
     *
     * @param promotions 促销实体
     */
    void updateEsGoodsIndex(T promotions);

    /**
     * 当前促销类型
     *
     * @return 当前促销类型
     */
    PromotionType getPromotionType();

    /**
     * 列表查询促销信息
     *
     * @param queryParam 查询参数，继承自继承促销查询参数
     * @param <S> 继承自基础促销查询参数的促销查询参数
     * @return 列表促销信息
     */
    <S extends BasePromotionQueryParam> List<T> listFindAll(S queryParam);

}
