package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.dto.ArticleDTO;
import com.chelvc.cloud.vehicle.api.param.ArticleModifyParam;
import com.chelvc.cloud.vehicle.api.param.ArticlePagingParam;
import com.chelvc.cloud.vehicle.server.copier.ArticleCopier;
import com.chelvc.cloud.vehicle.server.dao.ArticleMapper;
import com.chelvc.cloud.vehicle.server.entity.Article;
import com.chelvc.cloud.vehicle.server.service.ArticleService;
import com.chelvc.framework.base.util.ResourceUtils;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.database.util.PagingUtils;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 文章业务操作实现
 *
 * @author Woody
 * @date 2023/5/2
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.ArticleService.class)
public class ArticleServiceImpl extends ServiceImpl<ArticleMapper, Article> implements ArticleService,
        com.chelvc.cloud.vehicle.api.service.ArticleService {

    @Override
    public Long addArticle(@NonNull ArticleModifyParam param) {
        Article article = ArticleCopier.INSTANCE.copying(param);
        this.save(article);
        return article.getId();
    }

    @Override
    public void updateArticle(@NonNull Long id, @NonNull ArticleModifyParam param) {
        Article article = ResourceUtils.required(this.getById(id), "文章不存在");
        ArticleCopier.INSTANCE.copying(param, article);
        this.updateById(article);
    }

    @Override
    public ArticleDTO getArticle(@NonNull Long id) {
        return this.convert(this.getById(id));
    }

    @Override
    public Pagination<ArticleDTO> getArticlePaging(@NonNull ArticlePagingParam param) {
        // 查询文章分页
        Page<Article> page = this.lambdaQuery()
                .like(StringUtils.hasText(param.getKeyword()), Article::getTitle, param.getKeyword())
                .orderByDesc(Article::getId).page(PagingUtils.convert(param.getPaging()));
        List<Article> records = page.getRecords();
        if (CollectionUtils.isEmpty(records)) {
            return Pagination.empty();
        }

        // 构建文章信息
        List<ArticleDTO> articles = records.stream().map(this::convert).collect(Collectors.toList());
        return PagingUtils.convert(page, articles);
    }

    /**
     * 转换文章信息
     *
     * @param article 文章
     * @return 文章
     */
    private ArticleDTO convert(Article article) {
        return ArticleCopier.INSTANCE.copying(article);
    }
}
