package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.param.EnquireReplyModifyParam;
import com.chelvc.cloud.vehicle.api.dto.EnquireReplyDTO;
import com.chelvc.cloud.vehicle.api.param.EnquireReplyPagingParam;
import com.chelvc.cloud.vehicle.server.copier.EnquireReplyCopier;
import com.chelvc.cloud.vehicle.server.dao.EnquireReplyMapper;
import com.chelvc.cloud.vehicle.server.entity.EnquireReply;
import com.chelvc.cloud.vehicle.server.service.EnquireReplyService;
import com.chelvc.framework.base.util.ResourceUtils;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.database.util.PagingUtils;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 询价回复业务操作实现
 *
 * @author Woody
 * @date 2023/5/2
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.EnquireReplyService.class)
public class EnquireReplyServiceImpl extends ServiceImpl<EnquireReplyMapper,EnquireReply> implements EnquireReplyService,
        com.chelvc.cloud.vehicle.api.service.EnquireReplyService{

    @Override
    public Long addEnquireReply(@NonNull EnquireReplyModifyParam param) {
        EnquireReply enquireReply = EnquireReplyCopier.INSTANCE.copying(param);
        this.save(enquireReply);
        return enquireReply.getId();
    }

    @Override
    public void updateEnquireReply(@NonNull Long id, @NonNull EnquireReplyModifyParam param) {
        EnquireReply enquireReply = ResourceUtils.required(this.getById(id), "询价回复不存在");
        EnquireReplyCopier.INSTANCE.copying(param, enquireReply);
        this.updateById(enquireReply);
    }

    @Override
    public EnquireReplyDTO getEnquireReply(@NonNull Long id) {
        return this.convert(this.getById(id));
    }

    @Override
    public Pagination<EnquireReplyDTO> getEnquireReplyPaging(@NonNull EnquireReplyPagingParam param) {
        // 查询询价回复分页
        Page<EnquireReply> page = this.lambdaQuery()
                .orderByDesc(EnquireReply::getId).page(PagingUtils.convert(param.getPaging()));
        List<EnquireReply> records = page.getRecords();
        if (CollectionUtils.isEmpty(records)) {
            return Pagination.empty();
        }

        // 构建询价回复信息
        List<EnquireReplyDTO> enquireReplies = records.stream().map(this::convert).collect(Collectors.toList());
        return PagingUtils.convert(page, enquireReplies);
    }

    /**
     * 转换询价回复信息
     *
     * @param enquireReply 询价回复
     * @return EnquireDTO 询价回复
     */
    private EnquireReplyDTO convert(EnquireReply enquireReply) {
        return EnquireReplyCopier.INSTANCE.copying(enquireReply);
    }
}
