package com.chelvc.cloud.vehicle.server.service.impl;

import java.util.Date;
import java.util.List;

import com.chelvc.cloud.vehicle.server.dao.HelpMapper;
import com.chelvc.cloud.vehicle.server.entity.Help;
import com.chelvc.cloud.vehicle.server.service.IHelpService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 帮助Service业务层处理
 * 
 * @author liude
 * @date 2023-11-08
 */
@Service
public class HelpServiceImpl implements IHelpService
{
    @Autowired
    private HelpMapper helpMapper;

    /**
     * 查询帮助
     * 
     * @param id 帮助主键
     * @return 帮助
     */
    @Override
    public Help selectHelpById(Long id)
    {
        return helpMapper.selectHelpById(id);
    }

    /**
     * 查询帮助列表
     * 
     * @param help 帮助
     * @return 帮助
     */
    @Override
    public List<Help> selectHelpList(Help help)
    {
        return helpMapper.selectHelpList(help);
    }

    /**
     * 新增帮助
     * 
     * @param help 帮助
     * @return 结果
     */
    @Override
    public int insertHelp(Help help)
    {
        help.setCreateTime(new Date());
        return helpMapper.insertHelp(help);
    }

    /**
     * 修改帮助
     * 
     * @param help 帮助
     * @return 结果
     */
    @Override
    public int updateHelp(Help help)
    {
        return helpMapper.updateHelp(help);
    }

    /**
     * 批量删除帮助
     * 
     * @param ids 需要删除的帮助主键
     * @return 结果
     */
    @Override
    public int deleteHelpByIds(Long[] ids)
    {
        return helpMapper.deleteHelpByIds(ids);
    }

    /**
     * 删除帮助信息
     * 
     * @param id 帮助主键
     * @return 结果
     */
    @Override
    public int deleteHelpById(Long id)
    {
        return helpMapper.deleteHelpById(id);
    }
}
