package com.chelvc.cloud.vehicle.server.service.impl;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.api.dto.ShareDTO;
import com.chelvc.cloud.vehicle.api.param.SharePagingParam;
import com.chelvc.cloud.vehicle.server.copier.ShareCopier;
import com.chelvc.cloud.vehicle.server.dao.ShareMapper;
import com.chelvc.cloud.vehicle.server.entity.Share;
import com.chelvc.cloud.vehicle.server.service.ShareService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.database.util.PagingUtils;
import lombok.NonNull;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

/**
 * 分享记录业务操作实现
 *
 * @author xp
 * @data 2023/3/31
 */
@DubboService(interfaceClass = com.chelvc.cloud.vehicle.api.service.ShareService.class)
public class ShareServiceImpl extends ServiceImpl<ShareMapper, Share> implements ShareService,
        com.chelvc.cloud.vehicle.api.service.ShareService{

    @Override
    public Long addShare() {
        Long userId = SessionContextHolder.getSession().getId();
        Share share = new Share();
        share.setUserId(userId);
        share.setCreateTime(new Date());
        this.save(share);
        return share.getId();
    }


    @Override
    public ShareDTO getShare(@NonNull Long id) {
        return this.convert(this.getById(id));
    }

    @Override
    public Pagination<ShareDTO> getSharePaging(@NonNull SharePagingParam param) {
        // todo 后端可以按用户名搜？
        // 查询分享记录分页
        Page<Share> page = this.lambdaQuery()
                .eq(StringUtils.hasText(param.getKeyword()), Share::getUserId, param.getKeyword())
                .orderByDesc(Share::getId).page(PagingUtils.convert(param.getPaging()));
        List<Share> records = page.getRecords();
        if (CollectionUtils.isEmpty(records)) {
            return Pagination.empty();
        }

        // 构建分享记录信息
        List<ShareDTO> shares = records.stream().map(this::convert).collect(Collectors.toList());
        return PagingUtils.convert(page, shares);
    }

    /**
     * 转换分享记录信息
     *
     * @param share 分享记录
     * @return 分享记录
     */
    private ShareDTO convert(Share share) {
        return ShareCopier.INSTANCE.copying(share);
    }
}
