package com.chelvc.cloud.vehicle.server.timetask.handler.impl.coupon;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.chelvc.cloud.vehicle.api.constant.UserCouponStatus;
import com.chelvc.cloud.vehicle.server.entity.UserCoupon;
import com.chelvc.cloud.vehicle.server.service.UserCouponService;
import com.chelvc.cloud.vehicle.server.timetask.handler.EveryDayExecute;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Calendar;
import java.util.Date;

/**
 * 优惠券状态监测
 *
 * @author qizai
 * @date 2023/11/16
 */
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
@Component
public class CouponExecute implements EveryDayExecute {

    /**
     * 过期常量，过期后或者使用后一定时间内，删除无效的优惠券，物理删除
     */
    static final int EXPIRATION_DAY = 3;

    private final UserCouponService userCouponService;

    /**
     * 检测优惠券的使用时间，超期未使用则失效
     * 此方法用于领取*天后失效优惠券使用
     */
    @Override
    public void execute() {
        //将过期优惠券变更为过期状态
        LambdaUpdateWrapper<UserCoupon> updateWrapper = new LambdaUpdateWrapper<UserCoupon>()
                .eq(UserCoupon::getStatus, UserCouponStatus.CLAIMED)
                .le(UserCoupon::getEndTime, new Date())
                .set(UserCoupon::getStatus, UserCouponStatus.EXPIRED);
        this.userCouponService.update(updateWrapper);

        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.DAY_OF_MONTH, calendar.get(Calendar.DAY_OF_MONTH) - EXPIRATION_DAY);
        Date removeTime = calendar.getTime();
        //删除过期/已使用的优惠券
        LambdaUpdateWrapper<UserCoupon> deleteWrapper = new LambdaUpdateWrapper<UserCoupon>()
                //如果结束时间小于 当前时间增加指定删除日期，则删除
                .le(UserCoupon::getEndTime, removeTime);
        this.userCouponService.remove(deleteWrapper);
    }

}
